Installation
------------
There are different ways of installing avtraj. Avtraj can either be installed via pip, conda, or manually.
We recommend that you install ``avtraj`` with ``pip``. ::

  $ pip install avtraj

You can install also ``avtraj`` with ``conda``, if you prefer. ::

  $ conda install -c conda-forge avtraj

Conda is a cross-platform package manager built especially for scientific
python. It will install ``mdtraj`` along with all dependencies from a
pre-compiled binary. If you don't have Python or the ``conda`` package
manager, we recommend starting with the `Anaconda Scientific Python
distribution <https://store.continuum.io/cshop/anaconda/>`_, which comes
pre-packaged with many of the core scientific python packages that MDTraj
uses (see below), or with the `Miniconda Python distribution
<http://conda.pydata.org/miniconda.html>`_, which is a bare-bones Python
installation.

MDTraj supports Python 2.7 or Python 3.4+ (recommended) on Mac, Linux, and
Windows.



Conda
+++++

Pip
+++

